sccoda.util.data\_generation
============================

.. automodule:: sccoda.util.data_generation

   
   
   .. rubric:: Functions

   .. autosummary::
   
      b_w_from_abs_change
      binary
      counts_from_first
      generate_case_control
      generate_normal_correlated
      generate_normal_uncorrelated
      generate_normal_xy_correlated
      generate_sparse_xy_correlated
      sparse_effect_matrix
   
   

   
   
   

   
   
   